@@ -3,7 +3,7 @@ from typing import Any, List, Optional
 from web3 import Web3
 from desk.api import Api
 from desk.auth import Auth
-from desk.types import CancelAllOrdersFn, CancelAllOrdersRequest, CancelOrderFn, CancelOrderRequest, CreatePlaceOrderFn, OrderRequest, OrderSide, OrderType, PlaceOrderResponse, TimeInForce
+from desk.types import CancelAllOrdersFn, CancelAllOrdersRequest, CancelOrderFn, CancelOrderRequest, CreatePlaceOrderFn, NetworkOption, OrderRequest, OrderSide, OrderType, PlaceOrderResponse, TimeInForce
 import desk.enum as enum
 from desk.constant.contract import VAULT_CONTRACT_ABI, ERC20_ABI_PATH
 from desk.constant.common import BROKER
@@ -23,20 +23,16 @@ class Exchange:
 
     Needed "Auth" object to be initialized
     """
-    def __init__(self, api_url: str, crm_url: str, auth: Auth = None):
+    def __init__(self, network: NetworkOption, auth: Auth = None):
         self.jwt = auth.jwt
         self.auth = auth
 
-        if not api_url:
-            raise Exception("api_url is required")
-
         if not auth or not auth.jwt:
             raise Exception("Auth is required")
 
-        self.api = Api(api_url=api_url, crm_url=crm_url, headers={
+        self.api = Api(network=network, headers={
                        "Authorization": f"Bearer {self.jwt}"})
-        self.api_url = api_url
-        self.crm_url = crm_url
+
         
         self.contract_address = get_contract_address(self.auth.chain_id)
 
@@ -52,6 +48,10 @@ class Exchange:
     def __create_place_order_payload(self, order: CreatePlaceOrderFn):
         nonce = generate_nonce()
 
+        order_type = convert_enum_to_string(order["orderType"])
+        side = convert_enum_to_string(order["side"])
+        symbol = convert_enum_to_string(order["symbol"])
+        
         payload: OrderRequest = {
             "nonce": str(nonce),
             "amount": order["amount"],
@@ -60,13 +60,13 @@ class Exchange:
             "broker_id": BROKER,
             "subaccount": self.auth.sub_account,
 
-            "order_type": convert_enum_to_string(order["orderType"]),
-            "side": convert_enum_to_string(order["side"]),
-            "symbol": convert_enum_to_string(order["symbol"]),
+            "order_type": order_type,
+            "side": side,
+            "symbol": symbol,
         }
 
         # TIF
-        if order["orderType"] == "Limit" or order["orderType"] == "Stop":
+        if order_type == "Limit" or order_type == "Stop":
             payload["time_in_force"] = convert_enum_to_string(order["timeInForce"])
 
         # Optional args
@@ -168,7 +168,7 @@ class Exchange:
             client_order_id (str): client order id to cancel
         """
         order: CancelOrderFn = {
-            "symbol": symbol,
+            "symbol": convert_enum_to_string(symbol),
             "orderDigest": order_digest,
             "isConditionalOrder": is_conditional_order,
             "waitForReply": wait_for_reply,
@@ -208,7 +208,7 @@ class Exchange:
         }
         return payload
     
-    def cancel_all_orders(self, symbol: str = None, is_conditional_order: bool = False, wait_for_reply: bool = False) -> Any:
+    def cancel_all_orders(self, symbol: str | enum.MarketSymbol = None, is_conditional_order: bool = False, wait_for_reply: bool = False) -> Any:
         """Cancel all orders
 
         Args:
@@ -217,7 +217,7 @@ class Exchange:
             wait_for_reply (bool): should api wait for reply
         """
         order: CancelAllOrdersFn = {
-            "symbol": symbol,
+            "symbol": convert_enum_to_string(symbol),
             "isConditionalOrder": is_conditional_order,
             "waitForReply": wait_for_reply,
         }
